************
Installation
************


Installing Prometheus
=====================

The easiest way to install Prometheus is with PyPi.  Note that you need to install "theprometheus",
but it will import with "prometheus".

.. code-block:: bash

    pip install theprometheus

To get the very latest version of the software, install it directly from GitHub.
    
.. code-block:: bash

    pip install git+https://github.com/dnidever/prometheus    


Dependencies
============

- numpy
- scipy
- astropy
- matplotlib
- sep
- photutils
- dlnpyutils
- scikit-image
